/***************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                 *
 *   mike.s@genion.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/**
 * my code playground/test case for app logic
 */
 
#include <stdio.h>
#include <qfile.h>
#include <qstringlist.h>

#include <kmountpoint.h>

#include "ipod.h"

using namespace itunesdb;

/* test program to debug the core stuff */

int main( int argc, char ** argv) {
    QStringList artistlist;
    IPod ipod;
    
    // try to find a mounted ipod
    KMountPoint::List currentmountpoints = KMountPoint::currentMountPoints();
    KMountPoint::List::Iterator mountiter = currentmountpoints.begin();
    for(; mountiter != currentmountpoints.end(); ++mountiter) {
        QString mountpoint = (*mountiter)->mountPoint();
        if(ipod.open(mountpoint)) {
            break;
        } else {
            printf("%s is not an iPod\n", mountpoint.ascii());
        }
    }
    
    if(!ipod.isOpen()) {
        fprintf(stderr, "no IPod found here\n");
        return -1;
    }

    if( !ipod.getItunesDBError().isEmpty()) {
        fprintf( stderr, "error: %s\n", ipod.getItunesDBError().ascii());
    }
    
    if( !ipod.getArtists( artistlist))
        printf("NO ARTISTS!!!!");
    
    for( QStringList::iterator artistiterator= artistlist.begin(); artistiterator!= artistlist.end(); ++artistiterator) {
        Artist * artist;
        printf("%s\n", (*artistiterator).ascii());
        if( ( artist= ipod.getArtistByName( *artistiterator)) == NULL) {
            printf("ARTIST NOT FOUND!!!");
        } else {
            for( ArtistIterator albumiterator( *artist); albumiterator.current(); ++albumiterator) {
                TrackList * album= albumiterator.current();
                printf("\t%s (%d,%d)\n", albumiterator.currentKey().ascii(), album->getNumTracks(), album->getMaxTrackNumber());
                TrackList::Iterator trackiterator= album->getTrackIDs();
                // test the new javalike trackiterator
                while( trackiterator.hasNext()) {
                    TrackMetadata * track = ipod.getTrackByID( trackiterator.next());
                    printf("\t\t%d - %s\n", track->getTrackNumber(), track->getTitle().ascii());
                }
            }
        }
    }
    
    // try to write
    ipod.writeItunesDB("/tmp/iTunesDB");
}
